# -*- coding: utf-8 -*-
"""
#calculation of surface air temperature over land, for tropics or mean temperature

@author: juliabrugger
"""

import numpy as np
import matplotlib.pyplot as plt
from mpl_toolkits.basemap import Basemap, addcyclic, shiftgrid
from scipy.interpolate import interp1d

lonlatpsdata=np.loadtxt('ModelOutputImpact_p2s_lonlat.dat')
lon=lonlatpsdata[0:17]
lat=lonlatpsdata[17:42]
latmid=lonlatpsdata[42:66]

pi_frac=(np.pi/180)*latmid[:]
weightsum=np.sum(np.cos(pi_frac))

#create grid for maps
lon2d, lat2d = np.meshgrid(lon, lat)
# Transforms lat/lon into plotting coordinates for projection; 
#not needed for equidistant cylindrical projection
#x, y = m(lon2d, lat2d)
x=lon2d
y=lat2d

 
namesp2s=np.array(['tsland']) 
Namevarlong=np.array(['land temperature (°C)'])

#year 0 from control runs:
Var=np.zeros((24,16))
newdata=np.loadtxt('ModelOutputImpact_p2s2204_500.dat')
newdata=newdata.reshape((3,24,16))
newdata1=np.loadtxt('ModelOutputImpact_p2soro1_2p1.dat')
newdata1=newdata1.reshape((2,24,16))                
tsur=newdata[1,:,:]

Frlnd=newdata1[0,:,:]
sst=newdata[2,:,:]
                
for m in range(0,24):
    for n in range(0,16):
        if Frlnd[m,n]==0:
            Var[m,n]=1000
        else:
            Var[m,n]=(tsur[m,n]-(1-Frlnd[m,n])*sst[m,n])/Frlnd[m,n]
                
Var=np.ma.masked_object(Var,1000)
                
Var_mean_zonal=np.sum(Var*Frlnd,axis=1)/np.sum(Frlnd,axis=1)#zonal mean
#print Var_mean_zonal
Land_mean_zonal=np.mean(Frlnd,axis=1)
Var_mean_zonal_weight=Var_mean_zonal[:]*Land_mean_zonal[:]*np.cos(pi_frac)[:]
#Var_mean_zonal_weight=Var_mean_zonal[:]*np.cos(pi_frac)[:]                
#weighted zonal mean           
#print Var_mean_zonal_weight
               
weightsum1=np.sum(np.cos(pi_frac)*Land_mean_zonal)
weightsum2=np.sum(np.cos(pi_frac[9:15])*Land_mean_zonal[9:15])
Var_mean_0=np.sum(Var_mean_zonal_weight,axis=0)/weightsum1 #mean
tropics_0=np.sum(Var_mean_zonal_weight[9:15])/weightsum2  

#print Var_mean_0
print tropics_0

#################################################################################################################################
#for continental temperatures preimpact year and after impact

restimename=['500_2p1_360']
timename=['2204','2205','2206','2207','2208','2209','2210','2211','2212','2213','2214','2215','2216','2217','2218','2219','2220']

Var_mean=np.zeros((len(restimename),len(namesp2s),len(timename)))

tropics=np.zeros((len(restimename),len(namesp2s),len(timename)))



for j in range(len(restimename)):
        print restimename[j]
        for k in range(len(namesp2s)):        
            for i in range(len(timename)): 
                Var=np.zeros((24,16))
                newdata=np.loadtxt('ModelOutputImpact_p2s'+timename[i]+'_'+restimename[j]+'.dat')
                newdata=newdata.reshape((3,24,16))
                newdata1=np.loadtxt('ModelOutputImpact_p2soro1_2p1.dat')
                newdata1=newdata1.reshape((2,24,16))                
                tsur=newdata[1,:,:]

                Frlnd=newdata1[0,:,:]
                sst=newdata[2,:,:]
                
                for m in range(0,24):
                    for n in range(0,16):
                        if Frlnd[m,n]==0:
                            Var[m,n]=1000
                        else:
                            Var[m,n]=(tsur[m,n]-(1-Frlnd[m,n])*sst[m,n])/Frlnd[m,n]
                Var=np.ma.masked_object(Var,1000)
                
                Var_mean_zonal=np.sum(Var*Frlnd,axis=1)/np.sum(Frlnd,axis=1)#zonal mean
                #print Var_mean_zonal
                Land_mean_zonal=np.mean(Frlnd,axis=1)
                Var_mean_zonal_weight=Var_mean_zonal[:]*Land_mean_zonal[:]*np.cos(pi_frac)[:]
                #Var_mean_zonal_weight=Var_mean_zonal[:]*np.cos(pi_frac)[:]                
                #weighted zonal mean           
                #print Var_mean_zonal_weight
               
                weightsum1=np.sum(np.cos(pi_frac)*Land_mean_zonal)
                weightsum2=np.sum(np.cos(pi_frac[9:15])*Land_mean_zonal[9:15])
                Var_mean[j,k,i]=np.sum(Var_mean_zonal_weight,axis=0)/weightsum1 #mean
                tropics[j,k,i]=np.sum(Var_mean_zonal_weight[9:15])/weightsum2                
        #print Var_mean[j,:,:]
        print tropics[j,:,:]
