# -*- coding: utf-8 -*-
"""
@author: juliabrugger
"""

import numpy as np
#from netCDF4 import Dataset
import matplotlib.pyplot as plt
import matplotlib.legend as lgd
from mpl_toolkits.basemap import Basemap, addcyclic, shiftgrid
from scipy.interpolate import interp1d
from matplotlib.patches import Rectangle

lonlatpsdata=np.loadtxt('ModelOutputImpact_p2s_lonlat.dat')
lon=lonlatpsdata[0:17]
lat=lonlatpsdata[17:42]
latmid=lonlatpsdata[42:66]

pi_frac=(np.pi/180)*latmid[:]
weightsum=np.sum(np.cos(pi_frac))


colorpaper=['b-','b--','b:',
            'r-','r--','r:',
            'g-','g--','g:'
]#,'m','k']

timename=np.arange(0,31,1)

restimename=['500_2p1_180','500_2p1_360','500_2p1_540',
             '500_4p3_180','500_4p3_360','500_4p3_540',
             '500_10p6_180','500_10p6_360','500_10p6_540',]

namesp2s=np.array(['ts'])  
Namevarlong_ts=np.array(['surface air temperature [°C]'])
Var_mean_ts=np.zeros((len(restimename),len(namesp2s),len(timename)))

#create grid for maps
lon2d, lat2d = np.meshgrid(lon, lat)
# Transforms lat/lon into plotting coordinates for projection; 
#not needed for equidistant cylindrical projection
#x, y = m(lon2d, lat2d)
x=lon2d
y=lat2d


#surface air temperature, Potsdam2 history

for j in range(len(restimename)):
    for k in range(len(namesp2s)):
        for i in range(len(timename)):
            newdata=np.loadtxt('ModelOutputImpact_p2h_'+restimename[j]+'.dat')
            newdata=newdata.reshape((1,100,24,16))
            Var=newdata[0,i,:,:]
        
            Var_mean_zonal=np.mean(Var,axis=1)#zonal mean
            Var_mean_zonal_weight=Var_mean_zonal[:]*np.cos(pi_frac)[:]#weighted zonal mean           
            Var_mean_ts[j,k,i]=np.sum(Var_mean_zonal_weight,axis=0)/weightsum #mean

#Control run
timenamecontrol=np.arange(0,31,1)
Var_mean_control_ts=np.zeros((1,len(namesp2s),len(timename)))
for k in range(len(namesp2s)):
    for i in range(len(timenamecontrol)):
        newdata=np.loadtxt('ModelOutputImpact_p2h_500.dat')
        newdata=newdata.reshape((1,100,24,16))
        Var=newdata[0,i,:,:]
        
        Var_mean_zonal=np.mean(Var,axis=1)#zonal mean
        Var_mean_zonal_weight=Var_mean_zonal[:]*np.cos(pi_frac)[:]#weighted zonal mean           
        Var_mean_control_ts[0,k,i]=np.sum(Var_mean_zonal_weight,axis=0)/weightsum #mean
        
###############################################################################
#sea ice fraction, ISIS
    
lonlatisisdata=np.loadtxt('ModelOutputImpact_isis_lonlat.dat')
lon=lonlatisisdata[0:97]
lat=lonlatisisdata[97:146]
latmidisis=lonlatisisdata[146:194]
lonmidisis=lonlatisisdata[194:290]

pi_frac_isis=(np.pi/180)*latmidisis[:]
weightsum=np.sum(np.cos(pi_frac_isis))

restimename=['500_2p1_180','500_2p1_360','500_2p1_540',
             '500_4p3_180','500_4p3_360','500_4p3_540',
             '500_10p6_180','500_10p6_360','500_10p6_540',]

timename=np.arange(0,31,1)
         
namesisis=np.array(['con_g'])  
Namevarlong=np.array(['sea ice fraction'])

Var_mean=np.zeros((len(restimename),len(namesisis),len(timename)))

#create grid for maps
lon2d, lat2d = np.meshgrid(lon,lat)
# Transforms lat/lon into plotting coordinates for projection; 
#not needed for equidistant cylindrical projection
#x, y = m(lon2d, lat2d)
x=lon2d
y=lat2d

for j in range(len(restimename)):
    for k in range(len(namesisis)):
        for i in range(len(timename)):
            newdata=np.loadtxt('ModelOutputImpact_isis_'+restimename[j]+'.dat')
            newdata=newdata.reshape((100,48,96))
            Var=newdata[i,:,:]  
            
            Var=np.ma.masked_less(Var,0)#masking values smaller 0; in convert to ascii masked values are set to -1

            Var_mean_zonal=np.ma.mean(Var,axis=1)#zonal mean
            Var_mean_zonal_weight=Var_mean_zonal[:]*np.cos(pi_frac_isis)[:]#weighted zonal mean           
            Var_mean[j,k,i]=np.sum(Var_mean_zonal_weight,axis=0)/weightsum #mean
            
#Control run
timenamecontrol=np.arange(0,31,1)
Var_mean_control=np.zeros((1,len(namesisis),len(timename)))
for k in range(len(namesisis)):
    for i in range(len(timenamecontrol)):
        newdata=np.loadtxt('ModelOutputImpact_isis_500.dat')
        newdata=newdata.reshape((1,100,48,96))
        Var=newdata[0,i,:,:]
        Var=np.ma.masked_less(Var,0)
        
        Var_mean_zonal=np.mean(Var,axis=1)#zonal mean
        Var_mean_zonal_weight=Var_mean_zonal[:]*np.cos(pi_frac_isis)[:]#weighted zonal mean           
        Var_mean_control[0,k,i]=np.sum(Var_mean_zonal_weight,axis=0)/weightsum #mean
        
#Plot with time, temperature in plot a, sea ice fraction in plot b

fg = plt.figure(figsize=(8,9))
adj = plt.subplots_adjust(hspace=0.3,wspace=0.3)

label=['2.1 yrs,180','2.1 yrs,360','2.1 yrs,540',
'4.3 yrs,180','4.3 yrs,360','4.3 yrs,360',
'10.6 yrs,180','10.6 yrs,360','10.6 yrs,540']

labelfill=['2.1 yrs','4.3 yrs','10.6 yrs']

#PLOT A

sp1=plt.subplot(2,1,1)
newnumber=np.array([0,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30])
line1,=plt.plot(newnumber,Var_mean_control_ts[0,0,:],'k--',linewidth=1.0,label='Control')      
for j in range(len(labelfill)): 
    plt.fill_between(newnumber,Var_mean_ts[0,0,:],Var_mean_ts[2,0,:],facecolor='black',alpha=0.5,label='2.1 yrs')
    plt.fill_between(newnumber,Var_mean_ts[3,0,:],Var_mean_ts[5,0,:],facecolor='grey',alpha=0.5,label='4.3 yrs')
    plt.fill_between(newnumber,Var_mean_ts[6,0,:],Var_mean_ts[8,0,:],facecolor='white',hatch='///',alpha=0.5,label='10.6 yrs')
#plt.axis('normal')
plt.xlim(0,30)
plt.xticks(np.arange(0, 35, 5))

p1 = Rectangle((0, 0), 1, 1, fc="grey")
p2 = Rectangle((0, 0), 1, 1, fc="white",hatch='///')
p3 = Rectangle((0, 0), 1, 1, fc="black")
plt.legend([line1,p3, p1,p2], ['Control','2.1 yrs', '4.3 yrs','10.6 yrs'],loc=4)
    
#plt.legend(fontsize=10,loc=4,handlelength=3.5)
figure_title=Namevarlong_ts[0]
plt.xlabel('time after impact [yrs]')
plt.ylabel(Namevarlong_ts[k])
sp1.set_title('(a)',x=-0.12,y=0.9,fontsize=12)


#PLOT B

label=['2.1 yrs,180','2.1 yrs,360','2.1 yrs,540',
'4.3 yrs,180','4.3 yrs,360','4.3 yrs,360',
'10.6 yrs,180','10.6 yrs,360','10.6 yrs,540']

labelfill=['2.1 yrs','4.3 yrs','10.6 yrs']

sp2=plt.subplot(2,1,2)  
newnumber=np.array([0,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30])
line1,=plt.plot(newnumber,Var_mean_control[0,k,:],'k--',linewidth=1.0,label='Control')      
for j in range(len(labelfill)): 
    plt.fill_between(newnumber,Var_mean[0,0,:],Var_mean[2,0,:],facecolor='black',alpha=0.5,label='2.1 yrs')
    plt.fill_between(newnumber,Var_mean[3,0,:],Var_mean[5,0,:],facecolor='grey',alpha=0.5,label='4.3 yrs')
    plt.fill_between(newnumber,Var_mean[6,0,:],Var_mean[8,0,:],facecolor='white',hatch='///',alpha=0.5,label='10.6 yrs')
#plt.axis('normal')
plt.xlim(0,30)
plt.xticks(np.arange(0, 35, 5))

p1 = Rectangle((0, 0), 1, 1, fc="grey")
p2 = Rectangle((0, 0), 1, 1, fc="white",hatch='///')
p3 = Rectangle((0, 0), 1, 1, fc="black")
plt.legend([line1,p3, p1,p2], ['Control','2.1 yrs', '4.3 yrs','10.6 yrs'],loc=1)
    
#plt.legend(fontsize=10,loc=4,handlelength=3.5)
figure_title=Namevarlong[0]
plt.xlabel('time after impact [yrs]')
plt.ylabel(Namevarlong[0])
sp2.set_title('(b)',x=-0.12,y=0.9,fontsize=12)
#plt.text(0.5, 120, figure_title,horizontalalignment='center',
#fontsize=15)
fg.savefig('ts_ice_500.pdf', format='pdf',bbox_inches='tight')
