# -*- coding: utf-8 -*-
"""
@author: juliabrugger
"""

import numpy as np
import matplotlib.pyplot as plt
import matplotlib.legend as lgd
from mpl_toolkits.basemap import Basemap, addcyclic, shiftgrid
from scipy.interpolate import interp1d

lonlatpsdata=np.loadtxt('ModelOutputImpact_p2s_lonlat.dat')
lon=lonlatpsdata[0:17]
lat=lonlatpsdata[17:42]
latmid=lonlatpsdata[42:66]

pi_frac=(np.pi/180)*latmid[:]
weightsum=np.sum(np.cos(pi_frac))

lonlatmomdata=np.loadtxt('ModelOutputImpact_smom_lonlat.dat')
lon0mom=lonlatmomdata[0:97]
lonmidmom=lonlatmomdata[97:193]
lat0mom=lonlatmomdata[193:242]
latmidmom=lonlatmomdata[242:290]

pi_frac_mom=(np.pi/180)*latmidmom[:]

restimename=['500_2p1_360']

minyear=[3]
         
namesp2s=np.array(['ts'])  
Namevarlong=np.array(['surface air temperature [°C]'])

Var_mean=np.zeros((len(restimename),len(namesp2s)))

#create grid for maps
lon2d, lat2d = np.meshgrid(lon, lat)

x=lon2d
y=lat2d

#continent contours
cont=np.loadtxt('ModelOutputImpact_continents.dat')
cont=cont.reshape((2,48,96))
cont=cont[0,:,:]#land ocean mask grid center
#grid for continents
lon2dcont, lat2dcont = np.meshgrid(lonmidmom, latmidmom)
xcont=lon2dcont
ycont=lat2dcont

for j in range(len(restimename)):

        for k in range(len(namesp2s)):
            
            fig, axes = plt.subplots(nrows=2, ncols=1)
            ax1=axes[0]
            ax2=axes[1]
        
            newdata=np.loadtxt('ModelOutputImpact_p2h_'+restimename[j]+'.dat')
            newdata=newdata.reshape((1,100,24,16))
            
            #year before impact
            Var=newdata[0,0,:,:]            
           
            #Determine Max and Min of Var to set colorbar
            maxvar=np.ceil(np.max(Var))
            minvar=np.floor(np.min(Var))
 

            fig.subplots_adjust(left=0., right=1., bottom=0.5, top=0.9,hspace=0.2)
            # Setup the map. See http://matplotlib.org/basemap/users/mapsetup.html
            # for other projections.
            m = Basemap(ax=ax1,projection='cyl', llcrnrlat=-90, urcrnrlat=90,\
            llcrnrlon=0, urcrnrlon=360, resolution='c')#cyl is equidistant cylindrical projection
            #m.drawcoastlines()
            m.drawmapboundary()
            m.drawparallels(np.arange(-90.,91.,30.),labels=[True,False,False,False],color='grey',fontsize=6)
            m.drawmeridians(np.arange(-180.,181.,60),labels=[False,False,False,True],color='grey',fontsize=6)
            
            cs = m.pcolor(x,y,Var,latlon=True,cmap=plt.cm.jet,vmin=-50,vmax=35)
            ax1.set_title('(a)',x=-0.12,y=0.95,fontsize=8)
            m.contour(xcont,ycont,cont,1,colors='k')

            Var_mean_zonal=np.mean(Var,axis=1)#zonal mean
            Var_mean_zonal_weight=Var_mean_zonal[:]*np.cos(pi_frac)[:]#weighted zonal mean 
            Var_mean=np.sum(Var_mean_zonal_weight,axis=0)/weightsum #mean           
            
            #################################################################################################
            #year with minimal temperature
            Var=newdata[0,minyear[j],:]
            
            
            #Determine Max and Min of Var to set colorbar
            maxvar=np.ceil(np.max(Var))
            minvar=np.floor(np.min(Var))
            #print minvar
            #print maxvar
            
            fig.subplots_adjust(left=0., right=1., bottom=0., top=1)
            # Setup the map. See http://matplotlib.org/basemap/users/mapsetup.html
            # for other projections.
            m = Basemap(ax=ax2,projection='cyl', llcrnrlat=-90, urcrnrlat=90,\
            llcrnrlon=0, urcrnrlon=360, resolution='c')#cyl is equidistant cylindrical projection
            #m.drawcoastlines()
            m.drawmapboundary()
            m.drawparallels(np.arange(-90.,91.,30.),labels=[True,False,False,False],color='grey',fontsize=6)
            m.drawmeridians(np.arange(-180.,181.,60),labels=[False,False,False,True],color='grey',fontsize=6)

            cs = m.pcolor(x,y,Var,latlon=True,cmap=plt.cm.jet,vmin=-50,vmax=35)
            ax2.set_title('(b)',x=-0.12,y=0.95,fontsize=8)
            m.contour(xcont,ycont,cont,1,colors='k')
                
            a=np.arange(-60,35,0.005)
            #t=(maxvar-minvar)/5
            ticksbar=np.arange(-60,35,10)
            #ticksbar=np.append(ticksbar,maxvar)
            fig.subplots_adjust(bottom=0.1)
            cbar_ax = fig.add_axes([0.2, 0.02, 0.6, 0.03])
            cbar=fig.colorbar(cs, cax=cbar_ax, orientation='horizontal',boundaries=a,ticks=ticksbar)
            cbar.set_label(Namevarlong[k],fontsize=6)
 
           
            cbar.ax.tick_params(labelsize=6)
            fig.savefig(namesp2s[k]+'_0&minyear_'+restimename[j]+'_map.pdf', format='pdf',bbox_inches='tight')                
                
            Var_mean_zonal=np.mean(Var,axis=1)#zonal mean
            Var_mean_zonal_weight=Var_mean_zonal[:]*np.cos(pi_frac)[:]#weighted zonal mean 
            Var_mean=np.sum(Var_mean_zonal_weight,axis=0)/weightsum #mean
