# -*- coding: utf-8 -*-
"""
Created on Mon Mar 14 19:03:57 2016

@author: juliabrugger
"""
import numpy as np
import matplotlib.pyplot as plt
from mpl_toolkits.basemap import Basemap, addcyclic, shiftgrid
from scipy.interpolate import interp1d


number=np.array([2207,2304,2704,3204])
timename=np.array([3,100,500,1000])
            
y=np.array([0,25.,50.,75.,100.,126.50817871,159.01193237,203.35920715,265.10632324,
            349.38116455,460.75689697,603.13934326,779.67095947,992.65313721,1243.48986816,
            1532.65319824,1859.67089844,2223.1394043,2620.75683594,3049.38110352,
            3505.10644531,3983.35913086,4479.01171875,4986.50830078,5500.])


x=np.array([-90,-86.25,-82.5,-78.75,-75.,-71.25,-67.5,-63.75,-60.,-56.25,-52.5,-48.75,
             -45.,-41.25,-37.5,-33.75,-30.,-26.25,-22.5,-18.75,-15.,-11.25,-7.5,
             -3.75,0.,3.75,7.5,11.25,15.,18.75,22.5,26.25,30.,33.75,37.5,41.25,
             45.,48.75,52.5,56.25,60.,63.75,67.5,71.25,75.,78.75,82.5,86.25,90.])
 
control=np.loadtxt('ModelOutputImpact_tempdepth_control.dat')
control=control.reshape((24,48,96))
          
Var_all=np.zeros((4,24,48))
for i in range(len(timename)):            
    newdata=np.loadtxt('ModelOutputImpact_tempdepth_500_2p1_360_'+str(timename[i])+'.dat')
    newdata=newdata.reshape((24,48,96))

    control=np.loadtxt('ModelOutputImpact_tempdepth_control_'+str(timename[i])+'.dat')
    control=control.reshape((24,48,96))
    
    newdata=newdata-control
    
    newdata=np.ma.masked_object(newdata,900)
    Var=np.ma.mean(newdata,axis=2)
    #Determine Max and Min of Var to set colorbar
    maxvar=np.ceil(np.max(Var))
    #minvar=np.floor(np.min(Var))
                                   
    #Map plot
    Mask=np.ma.filled(Var,fill_value=900)
    for k in range(0,24):
        for l in range(0,48):
            if Mask[k,l]==900:
                Mask[k,l]=900
            else:
                Mask[k,l]=1

    Mask =np.ma.masked_object(Mask,900)
    Var=Var*Mask
    Var_all[i,:,:]=Var

Var_all=np.ma.masked_object(Var_all,0)

#Plot in 4 subplots

fg = plt.figure(figsize=(11,8))
adj = plt.subplots_adjust(hspace=0.3,wspace=0.3)

cmap=plt.cm.seismic

sp1=plt.subplot(4,1,1)
cs =plt.pcolormesh(x,y,Var_all[0,:,:],vmin=-3,vmax=3,cmap='seismic')
sp1.set_title('(a)',x=-0.12,y=0.9,fontsize=12)
cmap.set_bad('k', 1.0)
plt.axis([-90,90,0,5500])
plt.ylabel('depth (m)')
plt.tick_params(
    axis='x',          # changes apply to the x-axis
    which='both',      # both major and minor ticks are affected
    bottom='off',      # ticks along the bottom edge are off
    top='off',         # ticks along the top edge are off
    labelbottom='off')
plt.gca().invert_yaxis()
plt.gca().tick_params(direction='out')

sp2=plt.subplot(4,1,2)
cs =plt.pcolormesh(x,y,Var_all[1,:,:],vmin=-3,vmax=3,cmap='seismic')
sp2.set_title('(b)',x=-0.12,y=0.9,fontsize=12)
cmap.set_bad('k', 1.0)
plt.axis([-90,90,0,5500])
plt.ylabel('depth (m)')
plt.tick_params(
    axis='x',          # changes apply to the x-axis
    which='both',      # both major and minor ticks are affected
    bottom='off',      # ticks along the bottom edge are off
    top='off',         # ticks along the top edge are off
    labelbottom='off')
plt.gca().invert_yaxis()
plt.gca().tick_params(direction='out')

sp3=plt.subplot(4,1,3)
cs =plt.pcolormesh(x,y,Var_all[2,:,:],vmin=-3,vmax=3,cmap='seismic')
sp3.set_title('(c)',x=-0.12,y=0.9,fontsize=12)
cmap.set_bad('k', 1.0)
plt.axis([-90,90,0,5500])
plt.ylabel('depth (m)')
plt.tick_params(
    axis='x',          # changes apply to the x-axis
    which='both',      # both major and minor ticks are affected
    bottom='off',      # ticks along the bottom edge are off
    top='off',         # ticks along the top edge are off
    labelbottom='off')
plt.gca().invert_yaxis()
plt.gca().tick_params(direction='out')

sp3=plt.subplot(4,1,4)
cs =plt.pcolormesh(x,y,Var_all[3,:,:],vmin=-3,vmax=3,cmap='seismic')
sp3.set_title('(d)',x=-0.12,y=0.9,fontsize=12)
cmap.set_bad('k', 1.0)    
#plt.axis([-88.125,88.125,0,5262.5])
plt.axis([-90,90,0,5500])
plt.ylabel('depth (m)')
plt.xlabel('latitude')
labels=['90°S','60°S','30°S','0°','30°N','60°N','90°N']
plt.xticks(np.arange(-90,100,30),labels)
plt.gca().invert_yaxis()
plt.gca().tick_params(direction='out')

plt.subplots_adjust(hspace=0.1)

a=np.arange(-3,4)
ticksbar=np.arange(-3,4,1)
cbar_ax = fg.add_axes([0.2, 0.02, 0.6, 0.03])
cbar=fg.colorbar(cs,cax=cbar_ax, orientation='horizontal') 
cbar.set_label('ocean temperature anomaly ($\degree$C)')
fg.savefig('tempdepthprofile_4years_diff.pdf', format='pdf',bbox_inches='tight')                
