# -*- coding: utf-8 -*-
"""
@author: juliabrugger
"""

import numpy as np
from netCDF4 import Dataset
import matplotlib.pyplot as plt
from mpl_toolkits.basemap import Basemap, addcyclic, shiftgrid
from scipy.interpolate import interp1d
import numpy.ma as ma
#from matplotlib.backends.backend_pdf import PdfPages
#import sys
#import decimal as dc

#np.set_printoptions(threshold=sys.maxint)#displays long lists and arrays in total

lonlatmomdata=np.loadtxt('ModelOutputImpact_smom_lonlat.dat')
lon=lonlatmomdata[0:97]
lonmid=lonlatmomdata[97:193]
lat=lonlatmomdata[193:242]
latmid=lonlatmomdata[242:290]

pi_frac=(np.pi/180)*latmid[:]
weightsum=np.sum(np.cos(pi_frac))

restimename1=['500_2p1_360']

timename1=['2204','2208']

namesmoms=np.array(['hmxl'])
Namevarlong=np.array(['mixed layer depth [m]'])

#2p1
Var_all=np.zeros((len(restimename1),len(namesmoms),len(timename1),48))
for j in range(len(restimename1)):
    for k in range(len(namesmoms)):        
        for i in range(len(timename1)):
                newdata=np.loadtxt('ModelOutputImpact_smom_hmxl_'+timename1[i]+'_'+restimename1[j]+'.dat')
                newdata=newdata.reshape((48,96))
            
                for m in range(0,48):
                    for n in range(0,96):
                        if newdata[m,n]!=-1:
                            newdata[m,n]=newdata[m,n]
                        else:
                            newdata[m,n]=np.NaN

                Var=np.nanmean(newdata,axis=1)
                Var_all[j,k,i,:]=Var
                
present=np.loadtxt('ModelOutputImpact_smom_hmxl_present.dat')
present=present.reshape((48,96))

for m in range(0,48):
    for n in range(0,96):
        if present[m,n]!=-1:
            present[m,n]=present[m,n]
        else:
            present[m,n]=np.NaN

present=np.nanmean(present,axis=1)

colorpaper=['r--','b-']

label1=['before impact','year 4 after impact']
for k in range(len(namesmoms)):   
    fig = plt.figure()
    newnumber=np.arange(-90,90,3.75) 
    for j in range(len(restimename1)): 
        plt.plot(newnumber,present/100,'g:',linewidth=2.0,label='present-day')
        plt.plot(newnumber,Var_all[j,k,0,:]/100,colorpaper[0],linewidth=2.0,label=label1[0])
        plt.plot(newnumber,Var_all[j,k,1,:]/100,colorpaper[1],linewidth=2.0,label=label1[1])
        plt.axis([-90,90,0,3000])
        plt.legend(fontsize=10,loc=8,handlelength=3.5)
        plt.xlabel('latitude')
        plt.ylabel(Namevarlong[k])
        labels=['90°S','60°S','30°S','0°','30°N','60°N','90°N']
        plt.xticks(np.arange(-90, 95, 30),labels)
        plt.gca().invert_yaxis()
        plt.gca().tick_params(direction='out')
        plt.show()   #to show the plot
        fig.savefig('hmxl_'+restimename1[j]+'.pdf', format='pdf',bbox_inches='tight')
